@@ -532,7 +532,6 @@ def list_engines(
         table.add_column("Type")
         table.add_column("User")
         table.add_column("Status")
-        table.add_column("Stage")
         table.add_column("Disk Usage")
         table.add_column("Uptime/Since")
         table.add_column("$/hour", justify="right")
@@ -555,15 +554,12 @@ def list_engines(
                 time_str = launch_time.strftime("%Y-%m-%d %H:%M")
                 disk_usage = "-"
 
-            stage_display = _colour_stage(stages_map.get(engine["instance_id"], "-"))
-
             table.add_row(
                 engine["name"],
                 engine["instance_id"],
                 engine["engine_type"],
                 engine["user"],
                 format_status(engine["state"], engine.get("ready")),
-                stage_display,
                 disk_usage,
                 time_str,
                 f"${hourly_cost:.2f}",
@@ -808,8 +804,13 @@ def terminate_engine(
 @engine_app.command("ssh")
 def ssh_engine(
     name_or_id: str = typer.Argument(help="Engine name or instance ID"),
+    admin: bool = typer.Option(False, "--admin", help="Connect as ec2-user instead of the engine owner user"),
 ):
-    """Connect to an engine via SSH."""
+    """Connect to an engine via SSH.
+
+    By default the CLI connects using the engine's owner username (the same one stored in the `User` tag).
+    Pass `--admin` to connect with the underlying [`ec2-user`] account for break-glass or debugging.
+    """
     username = check_aws_sso()
 
     # Get all engines to resolve name
@@ -825,8 +826,8 @@ def ssh_engine(
         console.print(f"[red]❌ Engine is not running (state: {engine['state']})[/red]")
         raise typer.Exit(1)
 
-    # Determine which SSH user to use (your username for your engines, ec2-user otherwise)
-    ssh_user = username if engine["user"] == username else "ec2-user"
+    # Choose SSH user
+    ssh_user = "ec2-user" if admin else username
 
     # Update SSH config
     console.print(f"Updating SSH config for [cyan]{engine['name']}[/cyan] (user: {ssh_user})...")
@@ -843,6 +844,7 @@ def config_ssh(
     all_engines: bool = typer.Option(
         False, "--all", "-a", help="Include all engines from all users"
     ),
+    admin: bool = typer.Option(False, "--admin", help="Generate entries that use ec2-user instead of per-engine owner user"),
 ):
     """Update SSH config with available engines."""
     username = check_aws_sso()
@@ -901,8 +903,8 @@ def config_ssh(
     # Add new entries if not cleaning
     if not clean:
         for engine in running_engines:
-            # Use engine owner's username when it's your own engine; otherwise default to ec2-user
-            ssh_user = engine['user'] if engine['user'] == username else 'ec2-user'
+            # Determine ssh user based on --admin flag
+            ssh_user = 'ec2-user' if admin else username
             new_lines.extend(
                 [
                     "",
@@ -932,26 +934,31 @@ def config_ssh(
             )
 
 
-@engine_app.command("keep-awake")
-def keep_awake(
+@engine_app.command("coffee")
+def coffee(
     name_or_id: str = typer.Argument(help="Engine name or instance ID"),
-    duration: str = typer.Argument("4h", help="Duration (e.g., 2h, 30m, 4h30m)"),
+    duration: str = typer.Argument("4h", help="Duration (e.g., 2h, 30m, 2h30m)"),
+    cancel: bool = typer.Option(False, "--cancel", help="Cancel existing coffee lock instead of extending"),
 ):
-    """Prevent an engine from auto-shutting down."""
+    """Pour ☕ for an engine: keeps it awake for the given duration (or cancel)."""
     username = check_aws_sso()
 
     # Parse duration
     import re
 
-    match = re.match(r"(?:(\d+)h)?(?:(\d+)m)?", duration)
-    if not match or (not match.group(1) and not match.group(2)):
-        console.print(f"[red]❌ Invalid duration format: {duration}[/red]")
-        console.print("Use format like: 4h, 30m, 2h30m")
-        raise typer.Exit(1)
+    if not cancel:
+        match = re.match(r"(?:(\d+)h)?(?:(\d+)m)?", duration)
+        if not match or (not match.group(1) and not match.group(2)):
+            console.print(f"[red]❌ Invalid duration format: {duration}[/red]")
+            console.print("Use format like: 4h, 30m, 2h30m")
+            raise typer.Exit(1)
 
-    hours = int(match.group(1) or 0)
-    minutes = int(match.group(2) or 0)
-    total_minutes = hours * 60 + minutes
+        hours = int(match.group(1) or 0)
+        minutes = int(match.group(2) or 0)
+        seconds_total = (hours * 60 + minutes) * 60
+        if seconds_total == 0:
+            console.print("[red]❌ Duration must be greater than zero[/red]")
+            raise typer.Exit(1)
 
     # Get all engines to resolve name
     response = make_api_request("GET", "/engines")
@@ -966,9 +973,10 @@ def keep_awake(
         console.print(f"[red]❌ Engine is not running (state: {engine['state']})[/red]")
         raise typer.Exit(1)
 
-    console.print(
-        f"Setting keep-awake for [cyan]{engine['name']}[/cyan] for {duration}..."
-    )
+    if cancel:
+        console.print(f"Cancelling coffee for [cyan]{engine['name']}[/cyan]…")
+    else:
+        console.print(f"Pouring coffee for [cyan]{engine['name']}[/cyan] for {duration}…")
 
     # Use SSM to run the engine keep-alive command
     ssm = boto3.client("ssm", region_name="us-east-1")
@@ -977,7 +985,9 @@ def keep_awake(
             InstanceIds=[engine["instance_id"]],
             DocumentName="AWS-RunShellScript",
             Parameters={
-                "commands": [f"engine keep-alive {duration}"],
+                "commands": [
+                    ("engine-coffee --cancel" if cancel else f"engine-coffee {seconds_total}")
+                ],
                 "executionTimeout": ["60"],
             },
         )
@@ -995,75 +1005,23 @@ def keep_awake(
                 break
 
         if result["Status"] == "Success":
-            console.print(f"[green]✓ Engine will stay awake for {duration}[/green]")
+            if cancel:
+                console.print("[green]✓ Coffee cancelled – auto-shutdown re-enabled[/green]")
+            else:
+                console.print(f"[green]✓ Coffee poured for {duration}[/green]")
             console.print(
                 "\n[dim]Note: Detached Docker containers (except dev containers) will also keep the engine awake.[/dim]"
             )
             console.print(
-                "[dim]Use keep-awake for nohup operations or other background tasks.[/dim]"
+                "[dim]Use coffee for nohup operations or other background tasks.[/dim]"
             )
         else:
             console.print(
-                f"[red]❌ Failed to set keep-awake: {result.get('StatusDetails', 'Unknown error')}[/red]"
+                f"[red]❌ Failed to manage coffee: {result.get('StatusDetails', 'Unknown error')}[/red]"
             )
 
     except ClientError as e:
-        console.print(f"[red]❌ Failed to set keep-awake: {e}[/red]")
-
-
-@engine_app.command("cancel-keep-awake")
-def cancel_keep_awake(
-    name_or_id: str = typer.Argument(help="Engine name or instance ID"),
-):
-    """Cancel keep-awake and re-enable auto-shutdown."""
-    username = check_aws_sso()
-
-    # Get all engines to resolve name
-    response = make_api_request("GET", "/engines")
-    if response.status_code != 200:
-        console.print("[red]❌ Failed to fetch engines[/red]")
-        raise typer.Exit(1)
-
-    engines = response.json().get("engines", [])
-    engine = resolve_engine(name_or_id, engines)
-
-    console.print(f"Cancelling keep-awake for [cyan]{engine['name']}[/cyan]...")
-
-    # Use SSM to run the engine cancel command
-    ssm = boto3.client("ssm", region_name="us-east-1")
-    try:
-        response = ssm.send_command(
-            InstanceIds=[engine["instance_id"]],
-            DocumentName="AWS-RunShellScript",
-            Parameters={
-                "commands": ["engine cancel"],
-                "executionTimeout": ["60"],
-            },
-        )
-
-        command_id = response["Command"]["CommandId"]
-
-        # Wait for command to complete
-        for _ in range(10):
-            time.sleep(1)
-            result = ssm.get_command_invocation(
-                CommandId=command_id,
-                InstanceId=engine["instance_id"],
-            )
-            if result["Status"] in ["Success", "Failed"]:
-                break
-
-        if result["Status"] == "Success":
-            console.print(
-                "[green]✓ Keep-awake cancelled, auto-shutdown re-enabled[/green]"
-            )
-        else:
-            console.print(
-                f"[red]❌ Failed to cancel keep-awake: {result.get('StatusDetails', 'Unknown error')}[/red]"
-            )
-
-    except ClientError as e:
-        console.print(f"[red]❌ Failed to cancel keep-awake: {e}[/red]")
+        console.print(f"[red]❌ Failed to manage coffee: {e}[/red]")
 
 
 @engine_app.command("resize")
@@ -1227,7 +1185,7 @@ def resize_engine(
         raise typer.Exit(1)
 
 
-@engine_app.command("create-ami")
+@engine_app.command("gami")
 def create_ami(
     name_or_id: str = typer.Argument(
         help="Engine name or instance ID to create AMI from"
@@ -2005,7 +1963,7 @@ def resize_studio(
 # ================= Idle timeout command =================
 
 
-@engine_app.command("idle-timeout")
+@engine_app.command("idle")
 def idle_timeout_cmd(
     name_or_id: str = typer.Argument(help="Engine name or instance ID"),
     set: Optional[str] = typer.Option(None, "--set", "-s", help="New timeout (e.g., 2h30m, 45m)")
